@@ -49,6 +49,10 @@ def albers_conus_crs():
     )
 
 
+def albers_conus_transform(res=4000):
+    return [res, 0.0, -2493045.0, 0.0, -res, 3310005.0]
+
+
 def albers_ak_extent():
     return "-2232345.0 344805.0 1494735.0 2380125.0"
 
@@ -71,6 +75,10 @@ def albers_ak_crs():
     )
 
 
+def albers_ak_transform(res=4000):
+    return [res, 0.0, -2232345.0, 0.0, -res, 2380125.0]
+
+
 def setup(name):
     if name == "jeremy":
         creds = "/Users/freeman/.config/gcloud/legacy_credentials/jeremy@carbonplan.org/adc.json"
